"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ClipType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ClipTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ClipType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NT_UNKNOWN: _ClipType.ValueType  # 0
    """"""
    CLIP_TYPE_OP: _ClipType.ValueType  # 1
    """跳过OP"""
    CLIP_TYPE_ED: _ClipType.ValueType  # 2
    """跳过ED"""
    CLIP_TYPE_HE: _ClipType.ValueType  # 3
    """"""
    CLIP_TYPE_MULTI_VIEW: _ClipType.ValueType  # 4
    """"""
    CLIP_TYPE_AD: _ClipType.ValueType  # 5
    """"""

class ClipType(_ClipType, metaclass=_ClipTypeEnumTypeWrapper):
    """跳过片头/片尾配置: Clip类型"""

NT_UNKNOWN: ClipType.ValueType  # 0
""""""
CLIP_TYPE_OP: ClipType.ValueType  # 1
"""跳过OP"""
CLIP_TYPE_ED: ClipType.ValueType  # 2
"""跳过ED"""
CLIP_TYPE_HE: ClipType.ValueType  # 3
""""""
CLIP_TYPE_MULTI_VIEW: ClipType.ValueType  # 4
""""""
CLIP_TYPE_AD: ClipType.ValueType  # 5
""""""
global___ClipType = ClipType

class _CodeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CodeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CodeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NOCODE: _CodeType.ValueType  # 0
    """默认"""
    CODE264: _CodeType.ValueType  # 1
    """H.264"""
    CODE265: _CodeType.ValueType  # 2
    """H.265"""

class CodeType(_CodeType, metaclass=_CodeTypeEnumTypeWrapper):
    """编码类型"""

NOCODE: CodeType.ValueType  # 0
"""默认"""
CODE264: CodeType.ValueType  # 1
"""H.264"""
CODE265: CodeType.ValueType  # 2
"""H.265"""
global___CodeType = CodeType

class _DrmTechType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DrmTechTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DrmTechType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NON: _DrmTechType.ValueType  # 0
    """"""
    FAIR_PLAY: _DrmTechType.ValueType  # 1
    """"""
    WIDE_VINE: _DrmTechType.ValueType  # 2
    """"""
    BILI_DRM: _DrmTechType.ValueType  # 3
    """"""

class DrmTechType(_DrmTechType, metaclass=_DrmTechTypeEnumTypeWrapper):
    """DRM技术类型"""

NON: DrmTechType.ValueType  # 0
""""""
FAIR_PLAY: DrmTechType.ValueType  # 1
""""""
WIDE_VINE: DrmTechType.ValueType  # 2
""""""
BILI_DRM: DrmTechType.ValueType  # 3
""""""
global___DrmTechType = DrmTechType

class _EpPublicityVideoType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _EpPublicityVideoTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_EpPublicityVideoType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PRE: _EpPublicityVideoType.ValueType  # 0
    """"""
    INLINE: _EpPublicityVideoType.ValueType  # 1
    """"""

class EpPublicityVideoType(_EpPublicityVideoType, metaclass=_EpPublicityVideoTypeEnumTypeWrapper):
    """"""

PRE: EpPublicityVideoType.ValueType  # 0
""""""
INLINE: EpPublicityVideoType.ValueType  # 1
""""""
global___EpPublicityVideoType = EpPublicityVideoType

class _InlineScene:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InlineSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InlineScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _InlineScene.ValueType  # 0
    """"""
    RELATED_EP: _InlineScene.ValueType  # 1
    """"""
    HE: _InlineScene.ValueType  # 2
    """"""
    SKIP: _InlineScene.ValueType  # 3
    """"""

class InlineScene(_InlineScene, metaclass=_InlineSceneEnumTypeWrapper):
    """"""

UNKNOWN: InlineScene.ValueType  # 0
""""""
RELATED_EP: InlineScene.ValueType  # 1
""""""
HE: InlineScene.ValueType  # 2
""""""
SKIP: InlineScene.ValueType  # 3
""""""
global___InlineScene = InlineScene

class _InlineType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InlineTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InlineType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TYPE_UNKNOWN: _InlineType.ValueType  # 0
    """"""
    TYPE_WHOLE: _InlineType.ValueType  # 1
    """"""
    TYPE_HE_CLIP: _InlineType.ValueType  # 2
    """"""
    TYPE_PREVIEW: _InlineType.ValueType  # 3
    """"""

class InlineType(_InlineType, metaclass=_InlineTypeEnumTypeWrapper):
    """"""

TYPE_UNKNOWN: InlineType.ValueType  # 0
""""""
TYPE_WHOLE: InlineType.ValueType  # 1
""""""
TYPE_HE_CLIP: InlineType.ValueType  # 2
""""""
TYPE_PREVIEW: InlineType.ValueType  # 3
""""""
global___InlineType = InlineType

class _LimitActionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LimitActionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LimitActionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LAT_UNKNOWN: _LimitActionType.ValueType  # 0
    """"""
    SHOW_LIMIT_DIALOG: _LimitActionType.ValueType  # 1
    """"""
    SKIP_CURRENT_EP: _LimitActionType.ValueType  # 2
    """"""

class LimitActionType(_LimitActionType, metaclass=_LimitActionTypeEnumTypeWrapper):
    """限制操作类型"""

LAT_UNKNOWN: LimitActionType.ValueType  # 0
""""""
SHOW_LIMIT_DIALOG: LimitActionType.ValueType  # 1
""""""
SKIP_CURRENT_EP: LimitActionType.ValueType  # 2
""""""
global___LimitActionType = LimitActionType

class _PlayErr:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PlayErrEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PlayErr.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NoErr: _PlayErr.ValueType  # 0
    """"""
    WithMultiDeviceLoginErr: _PlayErr.ValueType  # 1
    """管控类型的错误码"""

class PlayErr(_PlayErr, metaclass=_PlayErrEnumTypeWrapper):
    """错误码"""

NoErr: PlayErr.ValueType  # 0
""""""
WithMultiDeviceLoginErr: PlayErr.ValueType  # 1
"""管控类型的错误码"""
global___PlayErr = PlayErr

class _SecurityLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SecurityLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SecurityLevel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LEVEL_UNKNOWN: _SecurityLevel.ValueType  # 0
    """"""
    LEVEL_L1: _SecurityLevel.ValueType  # 1
    """"""
    LEVEL_L2: _SecurityLevel.ValueType  # 2
    """"""
    LEVEL_L3: _SecurityLevel.ValueType  # 3
    """"""

class SecurityLevel(_SecurityLevel, metaclass=_SecurityLevelEnumTypeWrapper):
    """DRM 安全等级"""

LEVEL_UNKNOWN: SecurityLevel.ValueType  # 0
""""""
LEVEL_L1: SecurityLevel.ValueType  # 1
""""""
LEVEL_L2: SecurityLevel.ValueType  # 2
""""""
LEVEL_L3: SecurityLevel.ValueType  # 3
""""""
global___SecurityLevel = SecurityLevel

@typing_extensions.final
class Animation(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class QnSvgaAnimationMapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    QN_SVGA_ANIMATION_MAP_FIELD_NUMBER: builtins.int
    @property
    def qn_svga_animation_map(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        qn_svga_animation_map: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["qn_svga_animation_map", b"qn_svga_animation_map"]) -> None: ...

global___Animation = Animation

@typing_extensions.final
class AudioMaterialProto(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    EDITION_FIELD_NUMBER: builtins.int
    PERSON_ID_FIELD_NUMBER: builtins.int
    PERSON_NAME_FIELD_NUMBER: builtins.int
    PERSON_AVATAR_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    audio_id: builtins.str
    """"""
    title: builtins.str
    """"""
    edition: builtins.str
    """"""
    person_id: builtins.int
    """"""
    person_name: builtins.str
    """"""
    person_avatar: builtins.str
    """"""
    @property
    def audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """"""
    def __init__(
        self,
        *,
        audio_id: builtins.str = ...,
        title: builtins.str = ...,
        edition: builtins.str = ...,
        person_id: builtins.int = ...,
        person_name: builtins.str = ...,
        person_avatar: builtins.str = ...,
        audio: collections.abc.Iterable[global___DashItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "audio_id", b"audio_id", "edition", b"edition", "person_avatar", b"person_avatar", "person_id", b"person_id", "person_name", b"person_name", "title", b"title"]) -> None: ...

global___AudioMaterialProto = AudioMaterialProto

@typing_extensions.final
class BadgeInfo(google.protobuf.message.Message):
    """角标信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    BG_GRADIENT_COLOR_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    text: builtins.str
    """角标文案"""
    bg_color: builtins.str
    """角标色值"""
    bg_color_night: builtins.str
    """角标色值-夜间模式"""
    text_color: builtins.str
    """文案色值"""
    @property
    def bg_gradient_color(self) -> global___GradientColor:
        """? 新版本客户端已弃用此项"""
    img: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        text_color: builtins.str = ...,
        bg_gradient_color: global___GradientColor | None = ...,
        img: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bg_gradient_color", b"bg_gradient_color"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_gradient_color", b"bg_gradient_color", "img", b"img", "text", b"text", "text_color", b"text_color"]) -> None: ...

global___BadgeInfo = BadgeInfo

@typing_extensions.final
class BottomDisplay(google.protobuf.message.Message):
    """Dialog组件: 底部显示"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    @property
    def title(self) -> global___TextInfo:
        """文案"""
    icon: builtins.str
    """图标"""
    def __init__(
        self,
        *,
        title: global___TextInfo | None = ...,
        icon: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["icon", b"icon", "title", b"title"]) -> None: ...

global___BottomDisplay = BottomDisplay

@typing_extensions.final
class ButtonInfo(google.protobuf.message.Message):
    """按钮信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class OrderReportParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_COLOR_FIELD_NUMBER: builtins.int
    BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    ACTION_TYPE_FIELD_NUMBER: builtins.int
    BADGE_INFO_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    LEFT_STRIKETHROUGH_TEXT_FIELD_NUMBER: builtins.int
    SIMPLE_TEXT_INFO_FIELD_NUMBER: builtins.int
    SIMPLE_BG_COLOR_FIELD_NUMBER: builtins.int
    SIMPLE_BG_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    BG_GRADIENT_COLOR_FIELD_NUMBER: builtins.int
    ORDER_REPORT_PARAMS_FIELD_NUMBER: builtins.int
    TASK_PARAM_FIELD_NUMBER: builtins.int
    PC_LINK_FIELD_NUMBER: builtins.int
    text: builtins.str
    """按钮文案"""
    text_color: builtins.str
    """按钮字体色值"""
    text_color_night: builtins.str
    """按钮字体色值-夜间模式"""
    bg_color: builtins.str
    """按钮背景色"""
    bg_color_night: builtins.str
    """按钮背景色-夜间模式"""
    link: builtins.str
    """按钮链接"""
    action_type: builtins.str
    """按钮动作类型"""
    @property
    def badge_info(self) -> global___BadgeInfo:
        """角标信息"""
    @property
    def report(self) -> global___Report:
        """埋点上报信息"""
    left_strikethrough_text: builtins.str
    """左侧删除线样式文案"""
    @property
    def simple_text_info(self) -> global___TextInfo:
        """缩略按钮文案信息"""
    simple_bg_color: builtins.str
    """缩略按钮背景色值"""
    simple_bg_color_night: builtins.str
    """缩略按钮字体色值-夜间模式"""
    @property
    def bg_gradient_color(self) -> global___GradientColor:
        """"""
    @property
    def order_report_params(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    @property
    def task_param(self) -> global___TaskParam:
        """"""
    pc_link: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
        bg_color: builtins.str = ...,
        bg_color_night: builtins.str = ...,
        link: builtins.str = ...,
        action_type: builtins.str = ...,
        badge_info: global___BadgeInfo | None = ...,
        report: global___Report | None = ...,
        left_strikethrough_text: builtins.str = ...,
        simple_text_info: global___TextInfo | None = ...,
        simple_bg_color: builtins.str = ...,
        simple_bg_color_night: builtins.str = ...,
        bg_gradient_color: global___GradientColor | None = ...,
        order_report_params: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        task_param: global___TaskParam | None = ...,
        pc_link: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge_info", b"badge_info", "bg_gradient_color", b"bg_gradient_color", "report", b"report", "simple_text_info", b"simple_text_info", "task_param", b"task_param"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_type", b"action_type", "badge_info", b"badge_info", "bg_color", b"bg_color", "bg_color_night", b"bg_color_night", "bg_gradient_color", b"bg_gradient_color", "left_strikethrough_text", b"left_strikethrough_text", "link", b"link", "order_report_params", b"order_report_params", "pc_link", b"pc_link", "report", b"report", "simple_bg_color", b"simple_bg_color", "simple_bg_color_night", b"simple_bg_color_night", "simple_text_info", b"simple_text_info", "task_param", b"task_param", "text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___ButtonInfo = ButtonInfo

@typing_extensions.final
class CastTips(google.protobuf.message.Message):
    """投屏限制. code = 0 时为无限制, 否则表示不不允许投屏并提示message"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "message", b"message"]) -> None: ...

global___CastTips = CastTips

@typing_extensions.final
class ClipInfo(google.protobuf.message.Message):
    """跳过片头/片尾配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATERIAL_NO_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    CLIP_TYPE_FIELD_NUMBER: builtins.int
    TOAST_TEXT_FIELD_NUMBER: builtins.int
    MULTI_VIEW_FIELD_NUMBER: builtins.int
    material_no: builtins.int
    """"""
    start: builtins.int
    """DASH分段始"""
    end: builtins.int
    """DASH分段终"""
    clip_type: global___ClipType.ValueType
    """Clip类型"""
    toast_text: builtins.str
    """跳过片头/片尾时的提示语"""
    @property
    def multi_view(self) -> global___MultiView:
        """"""
    def __init__(
        self,
        *,
        material_no: builtins.int = ...,
        start: builtins.int = ...,
        end: builtins.int = ...,
        clip_type: global___ClipType.ValueType = ...,
        toast_text: builtins.str = ...,
        multi_view: global___MultiView | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["multi_view", b"multi_view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["clip_type", b"clip_type", "end", b"end", "material_no", b"material_no", "multi_view", b"multi_view", "start", b"start", "toast_text", b"toast_text"]) -> None: ...

global___ClipInfo = ClipInfo

@typing_extensions.final
class ContinuePlayInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTINUE_PLAY_EP_ID_FIELD_NUMBER: builtins.int
    continue_play_ep_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        continue_play_ep_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["continue_play_ep_id", b"continue_play_ep_id"]) -> None: ...

global___ContinuePlayInfo = ContinuePlayInfo

@typing_extensions.final
class Coupon(google.protobuf.message.Message):
    """优惠券"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUPON_TOKEN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    USE_DESC_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESC_FIELD_NUMBER: builtins.int
    PAY_BUTTON_TEXT_FIELD_NUMBER: builtins.int
    PAY_BUTTON_TEXT_LINE_THROUGH_FIELD_NUMBER: builtins.int
    REAL_AMOUNT_FIELD_NUMBER: builtins.int
    EXPIRE_TIME_FIELD_NUMBER: builtins.int
    OTYPE_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    coupon_token: builtins.str
    """优惠券token"""
    type: builtins.int
    """优惠券类型
    1:折扣券 2:满减券 3:兑换券
    """
    value: builtins.str
    """优惠券面值"""
    use_desc: builtins.str
    """优惠券使用描述"""
    title: builtins.str
    """优惠券标题"""
    desc: builtins.str
    """优惠券描述"""
    pay_button_text: builtins.str
    """优惠券支付按钮文案"""
    pay_button_text_line_through: builtins.str
    """优惠券支付按钮删除线文案"""
    real_amount: builtins.str
    """实付金额"""
    @property
    def expire_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """使用过期时间"""
    otype: builtins.int
    """"""
    amount: builtins.str
    """"""
    def __init__(
        self,
        *,
        coupon_token: builtins.str = ...,
        type: builtins.int = ...,
        value: builtins.str = ...,
        use_desc: builtins.str = ...,
        title: builtins.str = ...,
        desc: builtins.str = ...,
        pay_button_text: builtins.str = ...,
        pay_button_text_line_through: builtins.str = ...,
        real_amount: builtins.str = ...,
        expire_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        otype: builtins.int = ...,
        amount: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["expire_time", b"expire_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "coupon_token", b"coupon_token", "desc", b"desc", "expire_time", b"expire_time", "otype", b"otype", "pay_button_text", b"pay_button_text", "pay_button_text_line_through", b"pay_button_text_line_through", "real_amount", b"real_amount", "title", b"title", "type", b"type", "use_desc", b"use_desc", "value", b"value"]) -> None: ...

global___Coupon = Coupon

@typing_extensions.final
class CouponInfo(google.protobuf.message.Message):
    """优惠券信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOAST_FIELD_NUMBER: builtins.int
    POP_WIN_FIELD_NUMBER: builtins.int
    @property
    def toast(self) -> global___CouponToast:
        """提示框信息"""
    @property
    def pop_win(self) -> global___PopWin:
        """弹窗信息"""
    def __init__(
        self,
        *,
        toast: global___CouponToast | None = ...,
        pop_win: global___PopWin | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pop_win", b"pop_win", "toast", b"toast"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pop_win", b"pop_win", "toast", b"toast"]) -> None: ...

global___CouponInfo = CouponInfo

@typing_extensions.final
class CouponTextInfo(google.protobuf.message.Message):
    """优惠券提示框文案信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    POSITIVE_PREVIEW_FIELD_NUMBER: builtins.int
    SECTION_FIELD_NUMBER: builtins.int
    positive_preview: builtins.str
    """提示框文案-播正片6分钟预览"""
    section: builtins.str
    """提示框文案-播非正片分节ep"""
    def __init__(
        self,
        *,
        positive_preview: builtins.str = ...,
        section: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["positive_preview", b"positive_preview", "section", b"section"]) -> None: ...

global___CouponTextInfo = CouponTextInfo

@typing_extensions.final
class CouponToast(google.protobuf.message.Message):
    """优惠券提示框信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_INFO_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    @property
    def text_info(self) -> global___CouponTextInfo:
        """提示框文案信息"""
    @property
    def button(self) -> global___ButtonInfo:
        """提示框按钮"""
    def __init__(
        self,
        *,
        text_info: global___CouponTextInfo | None = ...,
        button: global___ButtonInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button", "text_info", b"text_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "text_info", b"text_info"]) -> None: ...

global___CouponToast = CouponToast

@typing_extensions.final
class DashItem(google.protobuf.message.Message):
    """dash条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    BASE_URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    WIDEVINE_PSSH_FIELD_NUMBER: builtins.int
    id: builtins.int
    """清晰度"""
    base_url: builtins.str
    """主线流"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """备用流"""
    bandwidth: builtins.int
    """带宽"""
    codecid: builtins.int
    """编码id"""
    md5: builtins.str
    """md5"""
    size: builtins.int
    """视频大小"""
    frame_rate: builtins.str
    """帧率"""
    widevine_pssh: builtins.str
    """DRM widevine 密钥"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        base_url: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        bandwidth: builtins.int = ...,
        codecid: builtins.int = ...,
        md5: builtins.str = ...,
        size: builtins.int = ...,
        frame_rate: builtins.str = ...,
        widevine_pssh: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url", b"backup_url", "bandwidth", b"bandwidth", "base_url", b"base_url", "codecid", b"codecid", "frame_rate", b"frame_rate", "id", b"id", "md5", b"md5", "size", b"size", "widevine_pssh", b"widevine_pssh"]) -> None: ...

global___DashItem = DashItem

@typing_extensions.final
class DashVideo(google.protobuf.message.Message):
    """dash视频流"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    BANDWIDTH_FIELD_NUMBER: builtins.int
    CODECID_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    AUDIO_ID_FIELD_NUMBER: builtins.int
    NO_REXCODE_FIELD_NUMBER: builtins.int
    FRAME_RATE_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    WIDEVINE_PSSH_FIELD_NUMBER: builtins.int
    base_url: builtins.str
    """主线流"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """备用流"""
    bandwidth: builtins.int
    """带宽"""
    codecid: builtins.int
    """编码id"""
    md5: builtins.str
    """md5"""
    size: builtins.int
    """大小"""
    audio_id: builtins.int
    """伴音质量id"""
    no_rexcode: builtins.bool
    """是否非全二压"""
    frame_rate: builtins.str
    """帧率"""
    width: builtins.int
    """宽"""
    height: builtins.int
    """高"""
    widevine_pssh: builtins.str
    """DRM 密钥"""
    def __init__(
        self,
        *,
        base_url: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        bandwidth: builtins.int = ...,
        codecid: builtins.int = ...,
        md5: builtins.str = ...,
        size: builtins.int = ...,
        audio_id: builtins.int = ...,
        no_rexcode: builtins.bool = ...,
        frame_rate: builtins.str = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
        widevine_pssh: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_id", b"audio_id", "backup_url", b"backup_url", "bandwidth", b"bandwidth", "base_url", b"base_url", "codecid", b"codecid", "frame_rate", b"frame_rate", "height", b"height", "md5", b"md5", "no_rexcode", b"no_rexcode", "size", b"size", "widevine_pssh", b"widevine_pssh", "width", b"width"]) -> None: ...

global___DashVideo = DashVideo

@typing_extensions.final
class DataControl(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEED_WATCH_PROGRESS_FIELD_NUMBER: builtins.int
    need_watch_progress: builtins.bool
    """"""
    def __init__(
        self,
        *,
        need_watch_progress: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["need_watch_progress", b"need_watch_progress"]) -> None: ...

global___DataControl = DataControl

@typing_extensions.final
class Dialog(google.protobuf.message.Message):
    """鉴权浮层"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STYLE_TYPE_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    BOTTOM_DESC_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    COUNT_DOWN_SEC_FIELD_NUMBER: builtins.int
    RIGHT_BOTTOM_DESC_FIELD_NUMBER: builtins.int
    BOTTOM_DISPLAY_FIELD_NUMBER: builtins.int
    PLAY_LIST_FIELD_NUMBER: builtins.int
    code: builtins.int
    """鉴权限制码"""
    msg: builtins.str
    """鉴权限制信息"""
    type: builtins.str
    """浮层类型"""
    style_type: builtins.str
    """浮层样式类型"""
    @property
    def config(self) -> global___DialogConfig:
        """浮层配置"""
    @property
    def title(self) -> global___TextInfo:
        """标题"""
    @property
    def subtitle(self) -> global___TextInfo:
        """副标题"""
    @property
    def image(self) -> global___ImageInfo:
        """图片信息"""
    @property
    def button(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ButtonInfo]:
        """按钮列表"""
    @property
    def bottom_desc(self) -> global___ButtonInfo:
        """底部描述"""
    @property
    def report(self) -> global___Report:
        """埋点上报信息"""
    count_down_sec: builtins.int
    """倒计时 秒"""
    @property
    def right_bottom_desc(self) -> global___TextInfo:
        """右下描述"""
    @property
    def bottom_display(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BottomDisplay]:
        """"""
    @property
    def play_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PlayList]:
        """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        msg: builtins.str = ...,
        type: builtins.str = ...,
        style_type: builtins.str = ...,
        config: global___DialogConfig | None = ...,
        title: global___TextInfo | None = ...,
        subtitle: global___TextInfo | None = ...,
        image: global___ImageInfo | None = ...,
        button: collections.abc.Iterable[global___ButtonInfo] | None = ...,
        bottom_desc: global___ButtonInfo | None = ...,
        report: global___Report | None = ...,
        count_down_sec: builtins.int = ...,
        right_bottom_desc: global___TextInfo | None = ...,
        bottom_display: collections.abc.Iterable[global___BottomDisplay] | None = ...,
        play_list: collections.abc.Iterable[global___PlayList] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bottom_desc", b"bottom_desc", "config", b"config", "image", b"image", "report", b"report", "right_bottom_desc", b"right_bottom_desc", "subtitle", b"subtitle", "title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bottom_desc", b"bottom_desc", "bottom_display", b"bottom_display", "button", b"button", "code", b"code", "config", b"config", "count_down_sec", b"count_down_sec", "image", b"image", "msg", b"msg", "play_list", b"play_list", "report", b"report", "right_bottom_desc", b"right_bottom_desc", "style_type", b"style_type", "subtitle", b"subtitle", "title", b"title", "type", b"type"]) -> None: ...

global___Dialog = Dialog

@typing_extensions.final
class DialogConfig(google.protobuf.message.Message):
    """鉴权浮层配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_SHOW_COVER_FIELD_NUMBER: builtins.int
    IS_ORIENTATION_ENABLE_FIELD_NUMBER: builtins.int
    IS_NESTED_SCROLL_ENABLE_FIELD_NUMBER: builtins.int
    IS_FORCE_HALFSCREEN_ENABLE_FIELD_NUMBER: builtins.int
    IS_BACKGROUND_TRANSLUCENT_ENABLE_FIELD_NUMBER: builtins.int
    is_show_cover: builtins.bool
    """是否显示高斯模糊背景图"""
    is_orientation_enable: builtins.bool
    """是否响应转屏"""
    is_nested_scroll_enable: builtins.bool
    """是否响应上滑吸顶"""
    is_force_halfscreen_enable: builtins.bool
    """是否强制竖屏"""
    is_background_translucent_enable: builtins.bool
    """是否启用背景半透明"""
    def __init__(
        self,
        *,
        is_show_cover: builtins.bool = ...,
        is_orientation_enable: builtins.bool = ...,
        is_nested_scroll_enable: builtins.bool = ...,
        is_force_halfscreen_enable: builtins.bool = ...,
        is_background_translucent_enable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_background_translucent_enable", b"is_background_translucent_enable", "is_force_halfscreen_enable", b"is_force_halfscreen_enable", "is_nested_scroll_enable", b"is_nested_scroll_enable", "is_orientation_enable", b"is_orientation_enable", "is_show_cover", b"is_show_cover"]) -> None: ...

global___DialogConfig = DialogConfig

@typing_extensions.final
class Dimension(google.protobuf.message.Message):
    """当前分辨率信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    ROTATE_FIELD_NUMBER: builtins.int
    width: builtins.int
    """宽"""
    height: builtins.int
    """长"""
    rotate: builtins.int
    """旋转角度"""
    def __init__(
        self,
        *,
        width: builtins.int = ...,
        height: builtins.int = ...,
        rotate: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["height", b"height", "rotate", b"rotate", "width", b"width"]) -> None: ...

global___Dimension = Dimension

@typing_extensions.final
class DolbyItem(google.protobuf.message.Message):
    """杜比音频信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[DolbyItem._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        NONE: DolbyItem._Type.ValueType  # 0
        """NONE"""
        COMMON: DolbyItem._Type.ValueType  # 1
        """普通杜比音效"""
        ATMOS: DolbyItem._Type.ValueType  # 2
        """全景杜比音效"""

    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        """杜比类型"""

    NONE: DolbyItem.Type.ValueType  # 0
    """NONE"""
    COMMON: DolbyItem.Type.ValueType  # 1
    """普通杜比音效"""
    ATMOS: DolbyItem.Type.ValueType  # 2
    """全景杜比音效"""

    TYPE_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    type: global___DolbyItem.Type.ValueType
    """杜比类型"""
    @property
    def audio(self) -> global___DashItem:
        """音频流"""
    def __init__(
        self,
        *,
        type: global___DolbyItem.Type.ValueType = ...,
        audio: global___DashItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["audio", b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio", b"audio", "type", b"type"]) -> None: ...

global___DolbyItem = DolbyItem

@typing_extensions.final
class EndPage(google.protobuf.message.Message):
    """播放结束后的尾页Dialog"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DIALOG_FIELD_NUMBER: builtins.int
    HIDE_FIELD_NUMBER: builtins.int
    @property
    def dialog(self) -> global___Dialog:
        """"""
    hide: builtins.bool
    """"""
    def __init__(
        self,
        *,
        dialog: global___Dialog | None = ...,
        hide: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dialog", b"dialog"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dialog", b"dialog", "hide", b"hide"]) -> None: ...

global___EndPage = EndPage

@typing_extensions.final
class EpInlineVideo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATERIAL_NO_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    material_no: builtins.int
    """"""
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        material_no: builtins.int = ...,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "material_no", b"material_no"]) -> None: ...

global___EpInlineVideo = EpInlineVideo

@typing_extensions.final
class EpisodeAdvertisementInfo(google.protobuf.message.Message):
    """剧集广告信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    FOLLOW_VIDEO_BNT_FLAG_FIELD_NUMBER: builtins.int
    NEXT_VIDEO_TITLE_FIELD_NUMBER: builtins.int
    NEXT_VIDEO_LINK_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    FOLLOW_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    title: builtins.str
    """"""
    link: builtins.str
    """"""
    follow_video_bnt_flag: builtins.int
    """"""
    next_video_title: builtins.str
    """"""
    next_video_link: builtins.str
    """"""
    cid: builtins.int
    """"""
    season_id: builtins.int
    """"""
    follow: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        title: builtins.str = ...,
        link: builtins.str = ...,
        follow_video_bnt_flag: builtins.int = ...,
        next_video_title: builtins.str = ...,
        next_video_link: builtins.str = ...,
        cid: builtins.int = ...,
        season_id: builtins.int = ...,
        follow: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "follow", b"follow", "follow_video_bnt_flag", b"follow_video_bnt_flag", "link", b"link", "next_video_link", b"next_video_link", "next_video_title", b"next_video_title", "season_id", b"season_id", "title", b"title"]) -> None: ...

global___EpisodeAdvertisementInfo = EpisodeAdvertisementInfo

@typing_extensions.final
class EpisodeInfo(google.protobuf.message.Message):
    """EP信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EP_ID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    AID_FIELD_NUMBER: builtins.int
    EP_STATUS_FIELD_NUMBER: builtins.int
    SEASON_INFO_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    INTERACTION_FIELD_NUMBER: builtins.int
    LONG_TITLE_FIELD_NUMBER: builtins.int
    ep_id: builtins.int
    """"""
    cid: builtins.int
    """"""
    aid: builtins.int
    """"""
    ep_status: builtins.int
    """"""
    @property
    def season_info(self) -> global___SeasonInfo:
        """"""
    cover: builtins.str
    """"""
    title: builtins.str
    """"""
    @property
    def interaction(self) -> global___Interaction:
        """"""
    long_title: builtins.str
    """"""
    def __init__(
        self,
        *,
        ep_id: builtins.int = ...,
        cid: builtins.int = ...,
        aid: builtins.int = ...,
        ep_status: builtins.int = ...,
        season_info: global___SeasonInfo | None = ...,
        cover: builtins.str = ...,
        title: builtins.str = ...,
        interaction: global___Interaction | None = ...,
        long_title: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["interaction", b"interaction", "season_info", b"season_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid", "cover", b"cover", "ep_id", b"ep_id", "ep_status", b"ep_status", "interaction", b"interaction", "long_title", b"long_title", "season_info", b"season_info", "title", b"title"]) -> None: ...

global___EpisodeInfo = EpisodeInfo

@typing_extensions.final
class EpPreVideo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    aid: builtins.int
    """"""
    cid: builtins.int
    """"""
    def __init__(
        self,
        *,
        aid: builtins.int = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid", b"aid", "cid", b"cid"]) -> None: ...

global___EpPreVideo = EpPreVideo

@typing_extensions.final
class EpPublicityVideo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Type:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _TypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[EpPublicityVideo._Type.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DATA_NOT_SET: EpPublicityVideo._Type.ValueType  # 0
        EP_PRE_VIDEO: EpPublicityVideo._Type.ValueType  # 2
        EP_INLINE: EpPublicityVideo._Type.ValueType  # 3

    class Type(_Type, metaclass=_TypeEnumTypeWrapper):
        """"""

    DATA_NOT_SET: EpPublicityVideo.Type.ValueType  # 0
    EP_PRE_VIDEO: EpPublicityVideo.Type.ValueType  # 2
    EP_INLINE: EpPublicityVideo.Type.ValueType  # 3

    TYPE_FIELD_NUMBER: builtins.int
    EP_PRE_VIDEO_FIELD_NUMBER: builtins.int
    EP_INLINE_VIDEO_FIELD_NUMBER: builtins.int
    type: global___EpPublicityVideo.Type.ValueType
    """"""
    @property
    def ep_pre_video(self) -> global___EpPreVideo:
        """"""
    @property
    def ep_inline_video(self) -> global___EpInlineVideo:
        """"""
    def __init__(
        self,
        *,
        type: global___EpPublicityVideo.Type.ValueType = ...,
        ep_pre_video: global___EpPreVideo | None = ...,
        ep_inline_video: global___EpInlineVideo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data", "ep_inline_video", b"ep_inline_video", "ep_pre_video", b"ep_pre_video"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "ep_inline_video", b"ep_inline_video", "ep_pre_video", b"ep_pre_video", "type", b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["data", b"data"]) -> typing_extensions.Literal["ep_pre_video", "ep_inline_video"] | None: ...

global___EpPublicityVideo = EpPublicityVideo

@typing_extensions.final
class Event(google.protobuf.message.Message):
    """事件"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHAKE_FIELD_NUMBER: builtins.int
    @property
    def shake(self) -> global___Shake:
        """震动"""
    def __init__(
        self,
        *,
        shake: global___Shake | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["shake", b"shake"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["shake", b"shake"]) -> None: ...

global___Event = Event

@typing_extensions.final
class FreyaConfig(google.protobuf.message.Message):
    """放映室提示语"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ISSUED_CNT_FIELD_NUMBER: builtins.int
    IS_ALWAYS_SHOW_FIELD_NUMBER: builtins.int
    SCREEN_NUMBER_FIELD_NUMBER: builtins.int
    FULL_SCREEN_NUMBER_FIELD_NUMBER: builtins.int
    desc: builtins.str
    """"""
    type: builtins.int
    """"""
    issued_cnt: builtins.int
    """"""
    is_always_show: builtins.bool
    """"""
    screen_number: builtins.int
    """"""
    full_screen_number: builtins.int
    """"""
    def __init__(
        self,
        *,
        desc: builtins.str = ...,
        type: builtins.int = ...,
        issued_cnt: builtins.int = ...,
        is_always_show: builtins.bool = ...,
        screen_number: builtins.int = ...,
        full_screen_number: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["desc", b"desc", "full_screen_number", b"full_screen_number", "is_always_show", b"is_always_show", "issued_cnt", b"issued_cnt", "screen_number", b"screen_number", "type", b"type"]) -> None: ...

global___FreyaConfig = FreyaConfig

@typing_extensions.final
class GradientColor(google.protobuf.message.Message):
    """渐变色信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_COLOR_FIELD_NUMBER: builtins.int
    END_COLOR_FIELD_NUMBER: builtins.int
    start_color: builtins.str
    """"""
    end_color: builtins.str
    """"""
    def __init__(
        self,
        *,
        start_color: builtins.str = ...,
        end_color: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_color", b"end_color", "start_color", b"start_color"]) -> None: ...

global___GradientColor = GradientColor

@typing_extensions.final
class HighDefinitionTrialInfo(google.protobuf.message.Message):
    """高画质试看信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIAL_ABLE_FIELD_NUMBER: builtins.int
    REMAINING_TIMES_FIELD_NUMBER: builtins.int
    START_FIELD_NUMBER: builtins.int
    TIME_LENGTH_FIELD_NUMBER: builtins.int
    START_TOAST_FIELD_NUMBER: builtins.int
    END_TOAST_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    QUALITY_OPEN_TIP_BTN_FIELD_NUMBER: builtins.int
    NO_LONGER_TRIAL_BTN_FIELD_NUMBER: builtins.int
    trial_able: builtins.bool
    """"""
    remaining_times: builtins.int
    """"""
    start: builtins.int
    """"""
    time_length: builtins.int
    """"""
    @property
    def start_toast(self) -> global___Toast:
        """"""
    @property
    def end_toast(self) -> global___Toast:
        """"""
    @property
    def report(self) -> global___Report:
        """"""
    @property
    def quality_open_tip_btn(self) -> global___ButtonInfo:
        """"""
    @property
    def no_longer_trial_btn(self) -> global___ButtonInfo:
        """"""
    def __init__(
        self,
        *,
        trial_able: builtins.bool = ...,
        remaining_times: builtins.int = ...,
        start: builtins.int = ...,
        time_length: builtins.int = ...,
        start_toast: global___Toast | None = ...,
        end_toast: global___Toast | None = ...,
        report: global___Report | None = ...,
        quality_open_tip_btn: global___ButtonInfo | None = ...,
        no_longer_trial_btn: global___ButtonInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_toast", b"end_toast", "no_longer_trial_btn", b"no_longer_trial_btn", "quality_open_tip_btn", b"quality_open_tip_btn", "report", b"report", "start_toast", b"start_toast"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_toast", b"end_toast", "no_longer_trial_btn", b"no_longer_trial_btn", "quality_open_tip_btn", b"quality_open_tip_btn", "remaining_times", b"remaining_times", "report", b"report", "start", b"start", "start_toast", b"start_toast", "time_length", b"time_length", "trial_able", b"trial_able"]) -> None: ...

global___HighDefinitionTrialInfo = HighDefinitionTrialInfo

@typing_extensions.final
class HistoryNode(google.protobuf.message.Message):
    """历史记录节点"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    node_id: builtins.int
    """节点ID"""
    title: builtins.str
    """节点标题"""
    cid: builtins.int
    """对应CID"""
    def __init__(
        self,
        *,
        node_id: builtins.int = ...,
        title: builtins.str = ...,
        cid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "node_id", b"node_id", "title", b"title"]) -> None: ...

global___HistoryNode = HistoryNode

@typing_extensions.final
class ImageInfo(google.protobuf.message.Message):
    """图片信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """图片链接"""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["url", b"url"]) -> None: ...

global___ImageInfo = ImageInfo

@typing_extensions.final
class Interaction(google.protobuf.message.Message):
    """交互信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HISTORY_NODE_FIELD_NUMBER: builtins.int
    GRAPH_VERSION_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    IS_INTERACTION_FIELD_NUMBER: builtins.int
    @property
    def history_node(self) -> global___HistoryNode:
        """历史节点"""
    graph_version: builtins.int
    """版本"""
    msg: builtins.str
    """交互消息"""
    is_interaction: builtins.bool
    """是否为交互"""
    def __init__(
        self,
        *,
        history_node: global___HistoryNode | None = ...,
        graph_version: builtins.int = ...,
        msg: builtins.str = ...,
        is_interaction: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["history_node", b"history_node"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["graph_version", b"graph_version", "history_node", b"history_node", "is_interaction", b"is_interaction", "msg", b"msg"]) -> None: ...

global___Interaction = Interaction

@typing_extensions.final
class MultiView(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUTTON_MATERIAL_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    AVID_FIELD_NUMBER: builtins.int
    button_material: builtins.str
    """"""
    ep_id: builtins.int
    """"""
    cid: builtins.int
    """"""
    avid: builtins.int
    """"""
    def __init__(
        self,
        *,
        button_material: builtins.str = ...,
        ep_id: builtins.int = ...,
        cid: builtins.int = ...,
        avid: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avid", b"avid", "button_material", b"button_material", "cid", b"cid", "ep_id", b"ep_id"]) -> None: ...

global___MultiView = MultiView

@typing_extensions.final
class PayTip(google.protobuf.message.Message):
    """大会员广告: 支付提示信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class OrderReportParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TITLE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SHOW_TYPE_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    BG_DAY_COLOR_FIELD_NUMBER: builtins.int
    BG_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    BG_LINE_COLOR_FIELD_NUMBER: builtins.int
    BG_NIGHT_LINE_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_NIGHT_COLOR_FIELD_NUMBER: builtins.int
    VIEW_START_TIME_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    URL_OPEN_TYPE_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    ANGLE_STYLE_FIELD_NUMBER: builtins.int
    REPORT_TYPE_FIELD_NUMBER: builtins.int
    ORDER_REPORT_PARAMS_FIELD_NUMBER: builtins.int
    GIANT_SCREEN_IMG_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    url: builtins.str
    """跳转链接"""
    icon: builtins.str
    """图标"""
    type: builtins.int
    """浮层类型"""
    show_type: builtins.int
    """显示类型"""
    img: builtins.str
    """图片信息"""
    bg_day_color: builtins.str
    """白天背景颜色"""
    bg_night_color: builtins.str
    """夜间背景颜色"""
    bg_line_color: builtins.str
    """白天线条颜色"""
    bg_night_line_color: builtins.str
    """夜间线条颜色"""
    text_color: builtins.str
    """文字颜色"""
    text_night_color: builtins.str
    """夜间文字颜色"""
    view_start_time: builtins.int
    """视图展示起始时间"""
    @property
    def button(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ButtonInfo]:
        """按钮列表"""
    url_open_type: builtins.int
    """跳转链接打开方式"""
    @property
    def report(self) -> global___Report:
        """埋点上报信息"""
    angle_style: builtins.int
    """角度样式"""
    report_type: builtins.int
    """埋点上报类型"""
    @property
    def order_report_params(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """订单埋点上报参数"""
    giant_screen_img: builtins.str
    """巨屏图片信息"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        url: builtins.str = ...,
        icon: builtins.str = ...,
        type: builtins.int = ...,
        show_type: builtins.int = ...,
        img: builtins.str = ...,
        bg_day_color: builtins.str = ...,
        bg_night_color: builtins.str = ...,
        bg_line_color: builtins.str = ...,
        bg_night_line_color: builtins.str = ...,
        text_color: builtins.str = ...,
        text_night_color: builtins.str = ...,
        view_start_time: builtins.int = ...,
        button: collections.abc.Iterable[global___ButtonInfo] | None = ...,
        url_open_type: builtins.int = ...,
        report: global___Report | None = ...,
        angle_style: builtins.int = ...,
        report_type: builtins.int = ...,
        order_report_params: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        giant_screen_img: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["report", b"report"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["angle_style", b"angle_style", "bg_day_color", b"bg_day_color", "bg_line_color", b"bg_line_color", "bg_night_color", b"bg_night_color", "bg_night_line_color", b"bg_night_line_color", "button", b"button", "giant_screen_img", b"giant_screen_img", "icon", b"icon", "img", b"img", "order_report_params", b"order_report_params", "report", b"report", "report_type", b"report_type", "show_type", b"show_type", "text_color", b"text_color", "text_night_color", b"text_night_color", "title", b"title", "type", b"type", "url", b"url", "url_open_type", b"url_open_type", "view_start_time", b"view_start_time"]) -> None: ...

global___PayTip = PayTip

@typing_extensions.final
class PlayAbilityConf(google.protobuf.message.Message):
    """禁用功能配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKGROUND_PLAY_DISABLE_FIELD_NUMBER: builtins.int
    FLIP_DISABLE_FIELD_NUMBER: builtins.int
    CAST_DISABLE_FIELD_NUMBER: builtins.int
    FEEDBACK_DISABLE_FIELD_NUMBER: builtins.int
    SUBTITLE_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_RATE_DISABLE_FIELD_NUMBER: builtins.int
    TIME_UP_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_MODE_DISABLE_FIELD_NUMBER: builtins.int
    SCALE_MODE_DISABLE_FIELD_NUMBER: builtins.int
    LIKE_DISABLE_FIELD_NUMBER: builtins.int
    DISLIKE_DISABLE_FIELD_NUMBER: builtins.int
    COIN_DISABLE_FIELD_NUMBER: builtins.int
    ELEC_DISABLE_FIELD_NUMBER: builtins.int
    SHARE_DISABLE_FIELD_NUMBER: builtins.int
    SCREEN_SHOT_DISABLE_FIELD_NUMBER: builtins.int
    LOCK_SCREEN_DISABLE_FIELD_NUMBER: builtins.int
    RECOMMEND_DISABLE_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_DISABLE_FIELD_NUMBER: builtins.int
    DEFINITION_DISABLE_FIELD_NUMBER: builtins.int
    SELECTIONS_DISABLE_FIELD_NUMBER: builtins.int
    NEXT_DISABLE_FIELD_NUMBER: builtins.int
    EDIT_DM_DISABLE_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_DISABLE_FIELD_NUMBER: builtins.int
    SHAKE_DISABLE_FIELD_NUMBER: builtins.int
    OUTER_DM_DISABLE_FIELD_NUMBER: builtins.int
    INNER_DM_DISABLE_FIELD_NUMBER: builtins.int
    FREYA_ENTER_DISABLE_FIELD_NUMBER: builtins.int
    DOLBY_DISABLE_FIELD_NUMBER: builtins.int
    FREYA_FULL_DISABLE_FIELD_NUMBER: builtins.int
    SKIP_OPED_SWITCH_DISABLE_FIELD_NUMBER: builtins.int
    RECORD_SCREEN_DISABLE_FIELD_NUMBER: builtins.int
    COLOR_OPTIMIZE_DISABLE_FIELD_NUMBER: builtins.int
    DUBBING_DISABLE_FIELD_NUMBER: builtins.int
    background_play_disable: builtins.bool
    """后台播放"""
    flip_disable: builtins.bool
    """镜像反转"""
    cast_disable: builtins.bool
    """投屏"""
    feedback_disable: builtins.bool
    """反馈"""
    subtitle_disable: builtins.bool
    """字幕"""
    playback_rate_disable: builtins.bool
    """播放速度"""
    time_up_disable: builtins.bool
    """定时停止"""
    playback_mode_disable: builtins.bool
    """播放方式"""
    scale_mode_disable: builtins.bool
    """画面尺寸"""
    like_disable: builtins.bool
    """赞"""
    dislike_disable: builtins.bool
    """踩"""
    coin_disable: builtins.bool
    """投币"""
    elec_disable: builtins.bool
    """充电"""
    share_disable: builtins.bool
    """分享"""
    screen_shot_disable: builtins.bool
    """截图"""
    lock_screen_disable: builtins.bool
    """锁定"""
    recommend_disable: builtins.bool
    """相关推荐"""
    playback_speed_disable: builtins.bool
    """播放速度"""
    definition_disable: builtins.bool
    """清晰度"""
    selections_disable: builtins.bool
    """选集"""
    next_disable: builtins.bool
    """下一集"""
    edit_dm_disable: builtins.bool
    """编辑弹幕"""
    small_window_disable: builtins.bool
    """小窗"""
    shake_disable: builtins.bool
    """震动"""
    outer_dm_disable: builtins.bool
    """外层面板弹幕设置"""
    inner_dm_disable: builtins.bool
    """三点内弹幕设置"""
    freya_enter_disable: builtins.bool
    """一起看入口"""
    dolby_disable: builtins.bool
    """杜比音效"""
    freya_full_disable: builtins.bool
    """全屏一起看入口"""
    skip_oped_switch_disable: builtins.bool
    """跳过片头片尾"""
    record_screen_disable: builtins.bool
    """录屏"""
    color_optimize_disable: builtins.bool
    """色觉优化"""
    dubbing_disable: builtins.bool
    """配音"""
    def __init__(
        self,
        *,
        background_play_disable: builtins.bool = ...,
        flip_disable: builtins.bool = ...,
        cast_disable: builtins.bool = ...,
        feedback_disable: builtins.bool = ...,
        subtitle_disable: builtins.bool = ...,
        playback_rate_disable: builtins.bool = ...,
        time_up_disable: builtins.bool = ...,
        playback_mode_disable: builtins.bool = ...,
        scale_mode_disable: builtins.bool = ...,
        like_disable: builtins.bool = ...,
        dislike_disable: builtins.bool = ...,
        coin_disable: builtins.bool = ...,
        elec_disable: builtins.bool = ...,
        share_disable: builtins.bool = ...,
        screen_shot_disable: builtins.bool = ...,
        lock_screen_disable: builtins.bool = ...,
        recommend_disable: builtins.bool = ...,
        playback_speed_disable: builtins.bool = ...,
        definition_disable: builtins.bool = ...,
        selections_disable: builtins.bool = ...,
        next_disable: builtins.bool = ...,
        edit_dm_disable: builtins.bool = ...,
        small_window_disable: builtins.bool = ...,
        shake_disable: builtins.bool = ...,
        outer_dm_disable: builtins.bool = ...,
        inner_dm_disable: builtins.bool = ...,
        freya_enter_disable: builtins.bool = ...,
        dolby_disable: builtins.bool = ...,
        freya_full_disable: builtins.bool = ...,
        skip_oped_switch_disable: builtins.bool = ...,
        record_screen_disable: builtins.bool = ...,
        color_optimize_disable: builtins.bool = ...,
        dubbing_disable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_play_disable", b"background_play_disable", "cast_disable", b"cast_disable", "coin_disable", b"coin_disable", "color_optimize_disable", b"color_optimize_disable", "definition_disable", b"definition_disable", "dislike_disable", b"dislike_disable", "dolby_disable", b"dolby_disable", "dubbing_disable", b"dubbing_disable", "edit_dm_disable", b"edit_dm_disable", "elec_disable", b"elec_disable", "feedback_disable", b"feedback_disable", "flip_disable", b"flip_disable", "freya_enter_disable", b"freya_enter_disable", "freya_full_disable", b"freya_full_disable", "inner_dm_disable", b"inner_dm_disable", "like_disable", b"like_disable", "lock_screen_disable", b"lock_screen_disable", "next_disable", b"next_disable", "outer_dm_disable", b"outer_dm_disable", "playback_mode_disable", b"playback_mode_disable", "playback_rate_disable", b"playback_rate_disable", "playback_speed_disable", b"playback_speed_disable", "recommend_disable", b"recommend_disable", "record_screen_disable", b"record_screen_disable", "scale_mode_disable", b"scale_mode_disable", "screen_shot_disable", b"screen_shot_disable", "selections_disable", b"selections_disable", "shake_disable", b"shake_disable", "share_disable", b"share_disable", "skip_oped_switch_disable", b"skip_oped_switch_disable", "small_window_disable", b"small_window_disable", "subtitle_disable", b"subtitle_disable", "time_up_disable", b"time_up_disable"]) -> None: ...

global___PlayAbilityConf = PlayAbilityConf

@typing_extensions.final
class PlayAbilityExtConf(google.protobuf.message.Message):
    """云控扩展配置信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CLOSE_SUBTITLE_FIELD_NUMBER: builtins.int
    FREYA_CONFIG_FIELD_NUMBER: builtins.int
    CAST_TIPS_FIELD_NUMBER: builtins.int
    allow_close_subtitle: builtins.bool
    """"""
    @property
    def freya_config(self) -> global___FreyaConfig:
        """"""
    @property
    def cast_tips(self) -> global___CastTips:
        """"""
    def __init__(
        self,
        *,
        allow_close_subtitle: builtins.bool = ...,
        freya_config: global___FreyaConfig | None = ...,
        cast_tips: global___CastTips | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cast_tips", b"cast_tips", "freya_config", b"freya_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_close_subtitle", b"allow_close_subtitle", "cast_tips", b"cast_tips", "freya_config", b"freya_config"]) -> None: ...

global___PlayAbilityExtConf = PlayAbilityExtConf

@typing_extensions.final
class PlayDubbingInfo(google.protobuf.message.Message):
    """播放配音信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BACKGROUND_AUDIO_FIELD_NUMBER: builtins.int
    ROLE_AUDIO_LIST_FIELD_NUMBER: builtins.int
    GUIDE_TEXT_FIELD_NUMBER: builtins.int
    @property
    def background_audio(self) -> global___AudioMaterialProto:
        """背景音频"""
    @property
    def role_audio_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoleAudioProto]:
        """角色音频列表"""
    guide_text: builtins.str
    """引导文本"""
    def __init__(
        self,
        *,
        background_audio: global___AudioMaterialProto | None = ...,
        role_audio_list: collections.abc.Iterable[global___RoleAudioProto] | None = ...,
        guide_text: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["background_audio", b"background_audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_audio", b"background_audio", "guide_text", b"guide_text", "role_audio_list", b"role_audio_list"]) -> None: ...

global___PlayDubbingInfo = PlayDubbingInfo

@typing_extensions.final
class PlayExtInfo(google.protobuf.message.Message):
    """播放扩展信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAY_DUBBING_INFO_FIELD_NUMBER: builtins.int
    @property
    def play_dubbing_info(self) -> global___PlayDubbingInfo:
        """播放配音信息"""
    def __init__(
        self,
        *,
        play_dubbing_info: global___PlayDubbingInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["play_dubbing_info", b"play_dubbing_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["play_dubbing_info", b"play_dubbing_info"]) -> None: ...

global___PlayExtInfo = PlayExtInfo

@typing_extensions.final
class PlayList(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    BADGE_INFO_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""
    title: builtins.str
    """"""
    cover: builtins.str
    """"""
    link: builtins.str
    """"""
    @property
    def badge_info(self) -> global___BadgeInfo:
        """"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        title: builtins.str = ...,
        cover: builtins.str = ...,
        link: builtins.str = ...,
        badge_info: global___BadgeInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["badge_info", b"badge_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["badge_info", b"badge_info", "cover", b"cover", "link", b"link", "season_id", b"season_id", "title", b"title"]) -> None: ...

global___PlayList = PlayList

@typing_extensions.final
class PlayViewBusinessInfo(google.protobuf.message.Message):
    """其他业务信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class QualityExtMapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        @property
        def value(self) -> global___QualityExtInfo: ...
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: global___QualityExtInfo | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ExpMapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    IS_PREVIEW_FIELD_NUMBER: builtins.int
    BP_FIELD_NUMBER: builtins.int
    MARLIN_TOKEN_FIELD_NUMBER: builtins.int
    PLAYBACK_SPEED_COLOR_FIELD_NUMBER: builtins.int
    CONTINUE_PLAY_INFO_FIELD_NUMBER: builtins.int
    CLIP_INFO_FIELD_NUMBER: builtins.int
    INLINE_TYPE_FIELD_NUMBER: builtins.int
    EP_WHOLE_DURATION_FIELD_NUMBER: builtins.int
    DIMENSION_FIELD_NUMBER: builtins.int
    QUALITY_EXT_MAP_FIELD_NUMBER: builtins.int
    EXP_MAP_FIELD_NUMBER: builtins.int
    DRM_TECH_TYPE_FIELD_NUMBER: builtins.int
    LIMIT_ACTION_TYPE_FIELD_NUMBER: builtins.int
    IS_DRM_FIELD_NUMBER: builtins.int
    RECORD_INFO_FIELD_NUMBER: builtins.int
    VIP_STATUS_FIELD_NUMBER: builtins.int
    IS_LIVE_PRE_FIELD_NUMBER: builtins.int
    EPISODE_INFO_FIELD_NUMBER: builtins.int
    EPISODE_ADVERTISEMENT_INFO_FIELD_NUMBER: builtins.int
    USER_STATUS_FIELD_NUMBER: builtins.int
    is_preview: builtins.bool
    """当前视频是否是预览"""
    bp: builtins.bool
    """用户是否承包过"""
    marlin_token: builtins.str
    """drm使用"""
    playback_speed_color: builtins.str
    """倍速动效色值"""
    @property
    def continue_play_info(self) -> global___ContinuePlayInfo:
        """"""
    @property
    def clip_info(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClipInfo]:
        """跳过片头/片尾配置"""
    inline_type: global___InlineType.ValueType
    """"""
    ep_whole_duration: builtins.int
    """"""
    @property
    def dimension(self) -> global___Dimension:
        """当前分辨率信息"""
    @property
    def quality_ext_map(self) -> google.protobuf.internal.containers.MessageMap[builtins.int, global___QualityExtInfo]:
        """"""
    @property
    def exp_map(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.int]:
        """"""
    drm_tech_type: global___DrmTechType.ValueType
    """DRM技术类型"""
    limit_action_type: builtins.int
    """"""
    is_drm: builtins.bool
    """"""
    @property
    def record_info(self) -> global___RecordInfo:
        """"""
    vip_status: builtins.int
    """"""
    is_live_pre: builtins.bool
    """"""
    @property
    def episode_info(self) -> global___EpisodeInfo:
        """"""
    @property
    def episode_advertisement_info(self) -> global___EpisodeAdvertisementInfo:
        """"""
    @property
    def user_status(self) -> global___UserStatus:
        """"""
    def __init__(
        self,
        *,
        is_preview: builtins.bool = ...,
        bp: builtins.bool = ...,
        marlin_token: builtins.str = ...,
        playback_speed_color: builtins.str = ...,
        continue_play_info: global___ContinuePlayInfo | None = ...,
        clip_info: collections.abc.Iterable[global___ClipInfo] | None = ...,
        inline_type: global___InlineType.ValueType = ...,
        ep_whole_duration: builtins.int = ...,
        dimension: global___Dimension | None = ...,
        quality_ext_map: collections.abc.Mapping[builtins.int, global___QualityExtInfo] | None = ...,
        exp_map: collections.abc.Mapping[builtins.str, builtins.int] | None = ...,
        drm_tech_type: global___DrmTechType.ValueType = ...,
        limit_action_type: builtins.int = ...,
        is_drm: builtins.bool = ...,
        record_info: global___RecordInfo | None = ...,
        vip_status: builtins.int = ...,
        is_live_pre: builtins.bool = ...,
        episode_info: global___EpisodeInfo | None = ...,
        episode_advertisement_info: global___EpisodeAdvertisementInfo | None = ...,
        user_status: global___UserStatus | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["continue_play_info", b"continue_play_info", "dimension", b"dimension", "episode_advertisement_info", b"episode_advertisement_info", "episode_info", b"episode_info", "record_info", b"record_info", "user_status", b"user_status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bp", b"bp", "clip_info", b"clip_info", "continue_play_info", b"continue_play_info", "dimension", b"dimension", "drm_tech_type", b"drm_tech_type", "ep_whole_duration", b"ep_whole_duration", "episode_advertisement_info", b"episode_advertisement_info", "episode_info", b"episode_info", "exp_map", b"exp_map", "inline_type", b"inline_type", "is_drm", b"is_drm", "is_live_pre", b"is_live_pre", "is_preview", b"is_preview", "limit_action_type", b"limit_action_type", "marlin_token", b"marlin_token", "playback_speed_color", b"playback_speed_color", "quality_ext_map", b"quality_ext_map", "record_info", b"record_info", "user_status", b"user_status", "vip_status", b"vip_status"]) -> None: ...

global___PlayViewBusinessInfo = PlayViewBusinessInfo

@typing_extensions.final
class PlayViewReply(google.protobuf.message.Message):
    """播放页信息-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VIDEO_INFO_FIELD_NUMBER: builtins.int
    PLAY_CONF_FIELD_NUMBER: builtins.int
    BUSINESS_FIELD_NUMBER: builtins.int
    EVENT_FIELD_NUMBER: builtins.int
    VIEW_INFO_FIELD_NUMBER: builtins.int
    PLAY_EXT_CONF_FIELD_NUMBER: builtins.int
    PLAY_EXT_INFO_FIELD_NUMBER: builtins.int
    @property
    def video_info(self) -> global___VideoInfo:
        """视频流信息"""
    @property
    def play_conf(self) -> global___PlayAbilityConf:
        """播放控件用户自定义配置"""
    @property
    def business(self) -> global___PlayViewBusinessInfo:
        """业务需要的其他信息"""
    @property
    def event(self) -> global___Event:
        """事件"""
    @property
    def view_info(self) -> global___ViewInfo:
        """展示信息"""
    @property
    def play_ext_conf(self) -> global___PlayAbilityExtConf:
        """自定义配置扩展信息"""
    @property
    def play_ext_info(self) -> global___PlayExtInfo:
        """播放扩展信息"""
    def __init__(
        self,
        *,
        video_info: global___VideoInfo | None = ...,
        play_conf: global___PlayAbilityConf | None = ...,
        business: global___PlayViewBusinessInfo | None = ...,
        event: global___Event | None = ...,
        view_info: global___ViewInfo | None = ...,
        play_ext_conf: global___PlayAbilityExtConf | None = ...,
        play_ext_info: global___PlayExtInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["business", b"business", "event", b"event", "play_conf", b"play_conf", "play_ext_conf", b"play_ext_conf", "play_ext_info", b"play_ext_info", "video_info", b"video_info", "view_info", b"view_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["business", b"business", "event", b"event", "play_conf", b"play_conf", "play_ext_conf", b"play_ext_conf", "play_ext_info", b"play_ext_info", "video_info", b"video_info", "view_info", b"view_info"]) -> None: ...

global___PlayViewReply = PlayViewReply

@typing_extensions.final
class PlayViewReq(google.protobuf.message.Message):
    """播放页信息-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EPID_FIELD_NUMBER: builtins.int
    CID_FIELD_NUMBER: builtins.int
    QN_FIELD_NUMBER: builtins.int
    FNVER_FIELD_NUMBER: builtins.int
    FNVAL_FIELD_NUMBER: builtins.int
    DOWNLOAD_FIELD_NUMBER: builtins.int
    FORCE_HOST_FIELD_NUMBER: builtins.int
    FOURK_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    FROM_SPMID_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    PREFER_CODEC_TYPE_FIELD_NUMBER: builtins.int
    IS_PREVIEW_FIELD_NUMBER: builtins.int
    ROOM_ID_FIELD_NUMBER: builtins.int
    IS_NEED_VIEW_INFO_FIELD_NUMBER: builtins.int
    SCENE_CONTROL_FIELD_NUMBER: builtins.int
    INLINE_SCENE_FIELD_NUMBER: builtins.int
    MATERIAL_NO_FIELD_NUMBER: builtins.int
    SECURITY_LEVEL_FIELD_NUMBER: builtins.int
    SEASON_ID_FIELD_NUMBER: builtins.int
    DATA_CONTROL_FIELD_NUMBER: builtins.int
    epid: builtins.int
    """剧集epid"""
    cid: builtins.int
    """视频cid"""
    qn: builtins.int
    """清晰度"""
    fnver: builtins.int
    """视频流版本"""
    fnval: builtins.int
    """视频流格式"""
    download: builtins.int
    """下载模式
    0:播放 1:flv下载 2:dash下载
    """
    force_host: builtins.int
    """流url强制是用域名
    0:允许使用ip 1:使用http 2:使用https
    """
    fourk: builtins.bool
    """是否4K"""
    spmid: builtins.str
    """当前页spm"""
    from_spmid: builtins.str
    """上一页spm"""
    teenagers_mode: builtins.int
    """青少年模式"""
    prefer_codec_type: global___CodeType.ValueType
    """视频编码"""
    is_preview: builtins.bool
    """是否强制请求预览视频"""
    room_id: builtins.int
    """一起看房间id"""
    is_need_view_info: builtins.bool
    """是否需要展示信息"""
    @property
    def scene_control(self) -> global___SceneControl:
        """场景控制"""
    inline_scene: global___InlineScene.ValueType
    """"""
    material_no: builtins.int
    """"""
    security_level: builtins.int
    """DRM 安全等级"""
    season_id: builtins.int
    """"""
    @property
    def data_control(self) -> global___DataControl:
        """"""
    def __init__(
        self,
        *,
        epid: builtins.int = ...,
        cid: builtins.int = ...,
        qn: builtins.int = ...,
        fnver: builtins.int = ...,
        fnval: builtins.int = ...,
        download: builtins.int = ...,
        force_host: builtins.int = ...,
        fourk: builtins.bool = ...,
        spmid: builtins.str = ...,
        from_spmid: builtins.str = ...,
        teenagers_mode: builtins.int = ...,
        prefer_codec_type: global___CodeType.ValueType = ...,
        is_preview: builtins.bool = ...,
        room_id: builtins.int = ...,
        is_need_view_info: builtins.bool = ...,
        scene_control: global___SceneControl | None = ...,
        inline_scene: global___InlineScene.ValueType = ...,
        material_no: builtins.int = ...,
        security_level: builtins.int = ...,
        season_id: builtins.int = ...,
        data_control: global___DataControl | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data_control", b"data_control", "scene_control", b"scene_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "data_control", b"data_control", "download", b"download", "epid", b"epid", "fnval", b"fnval", "fnver", b"fnver", "force_host", b"force_host", "fourk", b"fourk", "from_spmid", b"from_spmid", "inline_scene", b"inline_scene", "is_need_view_info", b"is_need_view_info", "is_preview", b"is_preview", "material_no", b"material_no", "prefer_codec_type", b"prefer_codec_type", "qn", b"qn", "room_id", b"room_id", "scene_control", b"scene_control", "season_id", b"season_id", "security_level", b"security_level", "spmid", b"spmid", "teenagers_mode", b"teenagers_mode"]) -> None: ...

global___PlayViewReq = PlayViewReq

@typing_extensions.final
class PopWin(google.protobuf.message.Message):
    """弹窗信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    COUPON_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    BOTTOM_TEXT_FIELD_NUMBER: builtins.int
    POP_TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    BOTTOM_DESC_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    POP_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """弹窗标题 老字段"""
    @property
    def coupon(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Coupon]:
        """优惠券列表"""
    @property
    def button(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ButtonInfo]:
        """弹窗按钮列表"""
    bottom_text: builtins.str
    """底部文案 老字段"""
    @property
    def pop_title(self) -> global___TextInfo:
        """弹窗标题 新字段"""
    @property
    def subtitle(self) -> global___TextInfo:
        """弹窗副标题"""
    @property
    def bottom_desc(self) -> global___ButtonInfo:
        """底部描述 新字段"""
    cover: builtins.str
    """弹窗小图"""
    pop_type: builtins.str
    """弹窗类型"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        coupon: collections.abc.Iterable[global___Coupon] | None = ...,
        button: collections.abc.Iterable[global___ButtonInfo] | None = ...,
        bottom_text: builtins.str = ...,
        pop_title: global___TextInfo | None = ...,
        subtitle: global___TextInfo | None = ...,
        bottom_desc: global___ButtonInfo | None = ...,
        cover: builtins.str = ...,
        pop_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bottom_desc", b"bottom_desc", "pop_title", b"pop_title", "subtitle", b"subtitle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bottom_desc", b"bottom_desc", "bottom_text", b"bottom_text", "button", b"button", "coupon", b"coupon", "cover", b"cover", "pop_title", b"pop_title", "pop_type", b"pop_type", "subtitle", b"subtitle", "title", b"title"]) -> None: ...

global___PopWin = PopWin

@typing_extensions.final
class PromptBar(google.protobuf.message.Message):
    """广告组件: 竖屏时视频下部提示栏"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_ICON_FIELD_NUMBER: builtins.int
    BG_IMAGE_FIELD_NUMBER: builtins.int
    BG_GRADIENT_COLOR_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    FULL_SCREEN_IP_ICON_FIELD_NUMBER: builtins.int
    FULL_SCREEN_BG_GRADIENT_COLOR_FIELD_NUMBER: builtins.int
    @property
    def title(self) -> global___TextInfo:
        """主标题, 如: "本片含大会员专享内容" """
    @property
    def sub_title(self) -> global___TextInfo:
        """副标题, 如: "成为大会员可免费看全部剧集" """
    sub_title_icon: builtins.str
    """副标题前面的icon"""
    bg_image: builtins.str
    """背景图"""
    @property
    def bg_gradient_color(self) -> global___GradientColor:
        """背景渐变色"""
    @property
    def button(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ButtonInfo]:
        """按钮"""
    @property
    def report(self) -> global___Report:
        """埋点上报信息"""
    full_screen_ip_icon: builtins.str
    """"""
    @property
    def full_screen_bg_gradient_color(self) -> global___GradientColor:
        """"""
    def __init__(
        self,
        *,
        title: global___TextInfo | None = ...,
        sub_title: global___TextInfo | None = ...,
        sub_title_icon: builtins.str = ...,
        bg_image: builtins.str = ...,
        bg_gradient_color: global___GradientColor | None = ...,
        button: collections.abc.Iterable[global___ButtonInfo] | None = ...,
        report: global___Report | None = ...,
        full_screen_ip_icon: builtins.str = ...,
        full_screen_bg_gradient_color: global___GradientColor | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bg_gradient_color", b"bg_gradient_color", "full_screen_bg_gradient_color", b"full_screen_bg_gradient_color", "report", b"report", "sub_title", b"sub_title", "title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_gradient_color", b"bg_gradient_color", "bg_image", b"bg_image", "button", b"button", "full_screen_bg_gradient_color", b"full_screen_bg_gradient_color", "full_screen_ip_icon", b"full_screen_ip_icon", "report", b"report", "sub_title", b"sub_title", "sub_title_icon", b"sub_title_icon", "title", b"title"]) -> None: ...

global___PromptBar = PromptBar

@typing_extensions.final
class QualityExtInfo(google.protobuf.message.Message):
    """云控拓展视频画质信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TRIAL_SUPPORT_FIELD_NUMBER: builtins.int
    trial_support: builtins.bool
    """是否支持试看"""
    def __init__(
        self,
        *,
        trial_support: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["trial_support", b"trial_support"]) -> None: ...

global___QualityExtInfo = QualityExtInfo

@typing_extensions.final
class RecordInfo(google.protobuf.message.Message):
    """备案信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORD_FIELD_NUMBER: builtins.int
    RECORD_ICON_FIELD_NUMBER: builtins.int
    record: builtins.str
    """记录"""
    record_icon: builtins.str
    """记录图标"""
    def __init__(
        self,
        *,
        record: builtins.str = ...,
        record_icon: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["record", b"record", "record_icon", b"record_icon"]) -> None: ...

global___RecordInfo = RecordInfo

@typing_extensions.final
class Report(google.protobuf.message.Message):
    """埋点上报信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOW_EVENT_ID_FIELD_NUMBER: builtins.int
    CLICK_EVENT_ID_FIELD_NUMBER: builtins.int
    EXTENDS_FIELD_NUMBER: builtins.int
    show_event_id: builtins.str
    """曝光事件"""
    click_event_id: builtins.str
    """点击事件"""
    extends: builtins.str
    """埋点透传参数"""
    def __init__(
        self,
        *,
        show_event_id: builtins.str = ...,
        click_event_id: builtins.str = ...,
        extends: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["click_event_id", b"click_event_id", "extends", b"extends", "show_event_id", b"show_event_id"]) -> None: ...

global___Report = Report

@typing_extensions.final
class ResponseUrl(google.protobuf.message.Message):
    """分段流条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ORDER_FIELD_NUMBER: builtins.int
    LENGTH_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BACKUP_URL_FIELD_NUMBER: builtins.int
    MD5_FIELD_NUMBER: builtins.int
    order: builtins.int
    """分段序号"""
    length: builtins.int
    """分段时长"""
    size: builtins.int
    """分段大小"""
    url: builtins.str
    """主线流"""
    @property
    def backup_url(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """备用流"""
    md5: builtins.str
    """md5"""
    def __init__(
        self,
        *,
        order: builtins.int = ...,
        length: builtins.int = ...,
        size: builtins.int = ...,
        url: builtins.str = ...,
        backup_url: collections.abc.Iterable[builtins.str] | None = ...,
        md5: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["backup_url", b"backup_url", "length", b"length", "md5", b"md5", "order", b"order", "size", b"size", "url", b"url"]) -> None: ...

global___ResponseUrl = ResponseUrl

@typing_extensions.final
class Rights(google.protobuf.message.Message):
    """权限信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAN_WATCH_FIELD_NUMBER: builtins.int
    can_watch: builtins.int
    """是否可以观看"""
    def __init__(
        self,
        *,
        can_watch: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["can_watch", b"can_watch"]) -> None: ...

global___Rights = Rights

@typing_extensions.final
class RoleAudioProto(google.protobuf.message.Message):
    """角色配音信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLE_ID_FIELD_NUMBER: builtins.int
    ROLE_NAME_FIELD_NUMBER: builtins.int
    ROLE_AVATAR_FIELD_NUMBER: builtins.int
    AUDIO_MATERIAL_LIST_FIELD_NUMBER: builtins.int
    role_id: builtins.int
    """角色ID"""
    role_name: builtins.str
    """角色名称"""
    role_avatar: builtins.str
    """角色头像"""
    @property
    def audio_material_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AudioMaterialProto]:
        """音频素材列表"""
    def __init__(
        self,
        *,
        role_id: builtins.int = ...,
        role_name: builtins.str = ...,
        role_avatar: builtins.str = ...,
        audio_material_list: collections.abc.Iterable[global___AudioMaterialProto] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_material_list", b"audio_material_list", "role_avatar", b"role_avatar", "role_id", b"role_id", "role_name", b"role_name"]) -> None: ...

global___RoleAudioProto = RoleAudioProto

@typing_extensions.final
class SceneControl(google.protobuf.message.Message):
    """场景控制"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAV_PLAYLIST_FIELD_NUMBER: builtins.int
    SMALL_WINDOW_FIELD_NUMBER: builtins.int
    PIP_FIELD_NUMBER: builtins.int
    WAS_HE_INLINE_FIELD_NUMBER: builtins.int
    IS_NEED_TRIAL_FIELD_NUMBER: builtins.int
    fav_playlist: builtins.bool
    """是否收藏播单"""
    small_window: builtins.bool
    """是否小窗"""
    pip: builtins.bool
    """是否画中画"""
    was_he_inline: builtins.bool
    """"""
    is_need_trial: builtins.bool
    """"""
    def __init__(
        self,
        *,
        fav_playlist: builtins.bool = ...,
        small_window: builtins.bool = ...,
        pip: builtins.bool = ...,
        was_he_inline: builtins.bool = ...,
        is_need_trial: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["fav_playlist", b"fav_playlist", "is_need_trial", b"is_need_trial", "pip", b"pip", "small_window", b"small_window", "was_he_inline", b"was_he_inline"]) -> None: ...

global___SceneControl = SceneControl

@typing_extensions.final
class Scheme(google.protobuf.message.Message):
    """方案"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ActionType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ActionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Scheme._ActionType.ValueType], builtins.type):  # noqa: F821
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        UNKNOWN: Scheme._ActionType.ValueType  # 0
        SHOW_TOAST: Scheme._ActionType.ValueType  # 1

    class ActionType(_ActionType, metaclass=_ActionTypeEnumTypeWrapper): ...
    UNKNOWN: Scheme.ActionType.ValueType  # 0
    SHOW_TOAST: Scheme.ActionType.ValueType  # 1

    ACTION_TYPE_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    action_type: global___Scheme.ActionType.ValueType
    """"""
    toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        action_type: global___Scheme.ActionType.ValueType = ...,
        toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action_type", b"action_type", "toast", b"toast"]) -> None: ...

global___Scheme = Scheme

@typing_extensions.final
class SeasonInfo(google.protobuf.message.Message):
    """PGC SEASON 信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEASON_ID_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    SEASON_STATUS_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    RIGHTS_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """PGC SEASON ID"""
    season_type: builtins.int
    """PGC SEASON 类型"""
    season_status: builtins.int
    """PGC SEASON 状态"""
    cover: builtins.str
    """封面"""
    title: builtins.str
    """标题"""
    @property
    def rights(self) -> global___Rights:
        """权限信息"""
    mode: builtins.int
    """模式"""
    def __init__(
        self,
        *,
        season_id: builtins.int = ...,
        season_type: builtins.int = ...,
        season_status: builtins.int = ...,
        cover: builtins.str = ...,
        title: builtins.str = ...,
        rights: global___Rights | None = ...,
        mode: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["rights", b"rights"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover", b"cover", "mode", b"mode", "rights", b"rights", "season_id", b"season_id", "season_status", b"season_status", "season_type", b"season_type", "title", b"title"]) -> None: ...

global___SeasonInfo = SeasonInfo

@typing_extensions.final
class SegmentVideo(google.protobuf.message.Message):
    """分段视频流"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEGMENT_FIELD_NUMBER: builtins.int
    @property
    def segment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResponseUrl]:
        """分段视频流列表"""
    def __init__(
        self,
        *,
        segment: collections.abc.Iterable[global___ResponseUrl] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["segment", b"segment"]) -> None: ...

global___SegmentVideo = SegmentVideo

@typing_extensions.final
class Shake(google.protobuf.message.Message):
    """震动"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    file: builtins.str
    """文件地址"""
    def __init__(
        self,
        *,
        file: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file"]) -> None: ...

global___Shake = Shake

@typing_extensions.final
class Stream(google.protobuf.message.Message):
    """视频流信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DASH_VIDEO_FIELD_NUMBER: builtins.int
    SEGMENT_VIDEO_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> global___StreamInfo:
        """元数据"""
    @property
    def dash_video(self) -> global___DashVideo:
        """dash流"""
    @property
    def segment_video(self) -> global___SegmentVideo:
        """分段流"""
    def __init__(
        self,
        *,
        info: global___StreamInfo | None = ...,
        dash_video: global___DashVideo | None = ...,
        segment_video: global___SegmentVideo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "dash_video", b"dash_video", "info", b"info", "segment_video", b"segment_video"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "dash_video", b"dash_video", "info", b"info", "segment_video", b"segment_video"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["content", b"content"]) -> typing_extensions.Literal["dash_video", "segment_video"] | None: ...

global___Stream = Stream

@typing_extensions.final
class StreamInfo(google.protobuf.message.Message):
    """流媒体元数据"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ERR_CODE_FIELD_NUMBER: builtins.int
    LIMIT_FIELD_NUMBER: builtins.int
    NEED_VIP_FIELD_NUMBER: builtins.int
    NEED_LOGIN_FIELD_NUMBER: builtins.int
    INTACT_FIELD_NUMBER: builtins.int
    ATTRIBUTE_FIELD_NUMBER: builtins.int
    NEW_DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_DESC_FIELD_NUMBER: builtins.int
    SUPERSCRIPT_FIELD_NUMBER: builtins.int
    SCHEME_FIELD_NUMBER: builtins.int
    SUPPORT_DRM_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """视频质量"""
    format: builtins.str
    """视频格式"""
    description: builtins.str
    """描述信息"""
    err_code: builtins.int
    """错误码"""
    @property
    def limit(self) -> global___StreamLimit:
        """流限制信息"""
    need_vip: builtins.bool
    """是否需要VIP"""
    need_login: builtins.bool
    """是否需要登录"""
    intact: builtins.bool
    """是否完整"""
    attribute: builtins.int
    """权限信息"""
    new_description: builtins.str
    """新版描述信息"""
    display_desc: builtins.str
    """显示描述信息"""
    superscript: builtins.str
    """上标"""
    @property
    def scheme(self) -> global___Scheme:
        """方案信息"""
    support_drm: builtins.bool
    """是否支持DRM"""
    subtitle: builtins.str
    """字幕信息"""
    def __init__(
        self,
        *,
        quality: builtins.int = ...,
        format: builtins.str = ...,
        description: builtins.str = ...,
        err_code: builtins.int = ...,
        limit: global___StreamLimit | None = ...,
        need_vip: builtins.bool = ...,
        need_login: builtins.bool = ...,
        intact: builtins.bool = ...,
        attribute: builtins.int = ...,
        new_description: builtins.str = ...,
        display_desc: builtins.str = ...,
        superscript: builtins.str = ...,
        scheme: global___Scheme | None = ...,
        support_drm: builtins.bool = ...,
        subtitle: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["limit", b"limit", "scheme", b"scheme"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attribute", b"attribute", "description", b"description", "display_desc", b"display_desc", "err_code", b"err_code", "format", b"format", "intact", b"intact", "limit", b"limit", "need_login", b"need_login", "need_vip", b"need_vip", "new_description", b"new_description", "quality", b"quality", "scheme", b"scheme", "subtitle", b"subtitle", "superscript", b"superscript", "support_drm", b"support_drm"]) -> None: ...

global___StreamInfo = StreamInfo

@typing_extensions.final
class StreamLimit(google.protobuf.message.Message):
    """清晰度不满足条件信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    MSG_FIELD_NUMBER: builtins.int
    title: builtins.str
    """标题"""
    uri: builtins.str
    """跳转地址"""
    msg: builtins.str
    """提示信息"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        uri: builtins.str = ...,
        msg: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg", b"msg", "title", b"title", "uri", b"uri"]) -> None: ...

global___StreamLimit = StreamLimit

@typing_extensions.final
class TaskParam(google.protobuf.message.Message):
    """任务参数信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_TYPE_FIELD_NUMBER: builtins.int
    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    TIPS_ID_FIELD_NUMBER: builtins.int
    task_type: builtins.str
    """任务类型"""
    activity_id: builtins.int
    """活动ID"""
    tips_id: builtins.int
    """提示ID"""
    def __init__(
        self,
        *,
        task_type: builtins.str = ...,
        activity_id: builtins.int = ...,
        tips_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id", b"activity_id", "task_type", b"task_type", "tips_id", b"tips_id"]) -> None: ...

global___TaskParam = TaskParam

@typing_extensions.final
class TextInfo(google.protobuf.message.Message):
    """文案信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """文案"""
    text_color: builtins.str
    """字体色值"""
    text_color_night: builtins.str
    """字体色值-夜间模式"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        text_color: builtins.str = ...,
        text_color_night: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "text_color", b"text_color", "text_color_night", b"text_color_night"]) -> None: ...

global___TextInfo = TextInfo

@typing_extensions.final
class Toast(google.protobuf.message.Message):
    """toast"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class OrderReportParamsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TEXT_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    SHOW_STYLE_TYPE_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    TOAST_TEXT_FIELD_NUMBER: builtins.int
    REPORT_FIELD_NUMBER: builtins.int
    ORDER_REPORT_PARAMS_FIELD_NUMBER: builtins.int
    text: builtins.str
    """toast文案 老字段"""
    @property
    def button(self) -> global___ButtonInfo:
        """toast按钮"""
    show_style_type: builtins.int
    """显示样式类型"""
    icon: builtins.str
    """图标"""
    @property
    def toast_text(self) -> global___TextInfo:
        """toast文案 新字段"""
    @property
    def report(self) -> global___Report:
        """埋点上报信息"""
    @property
    def order_report_params(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        button: global___ButtonInfo | None = ...,
        show_style_type: builtins.int = ...,
        icon: builtins.str = ...,
        toast_text: global___TextInfo | None = ...,
        report: global___Report | None = ...,
        order_report_params: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button", "report", b"report", "toast_text", b"toast_text"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "icon", b"icon", "order_report_params", b"order_report_params", "report", b"report", "show_style_type", b"show_style_type", "text", b"text", "toast_text", b"toast_text"]) -> None: ...

global___Toast = Toast

@typing_extensions.final
class UserStatus(google.protobuf.message.Message):
    """用户状态信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAY_CHECK_FIELD_NUMBER: builtins.int
    SPONSOR_FIELD_NUMBER: builtins.int
    WATCH_PROGRESS_FIELD_NUMBER: builtins.int
    AID_WATCH_PROGRESS_FIELD_NUMBER: builtins.int
    pay_check: builtins.bool
    """是否支付"""
    sponsor: builtins.bool
    """是否承包"""
    @property
    def watch_progress(self) -> global___WatchProgress:
        """观看进度"""
    @property
    def aid_watch_progress(self) -> global___WatchProgress:
        """系列观看进度"""
    def __init__(
        self,
        *,
        pay_check: builtins.bool = ...,
        sponsor: builtins.bool = ...,
        watch_progress: global___WatchProgress | None = ...,
        aid_watch_progress: global___WatchProgress | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aid_watch_progress", b"aid_watch_progress", "watch_progress", b"watch_progress"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aid_watch_progress", b"aid_watch_progress", "pay_check", b"pay_check", "sponsor", b"sponsor", "watch_progress", b"watch_progress"]) -> None: ...

global___UserStatus = UserStatus

@typing_extensions.final
class VideoInfo(google.protobuf.message.Message):
    """视频url信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUALITY_FIELD_NUMBER: builtins.int
    FORMAT_FIELD_NUMBER: builtins.int
    TIMELENGTH_FIELD_NUMBER: builtins.int
    VIDEO_CODECID_FIELD_NUMBER: builtins.int
    STREAM_LIST_FIELD_NUMBER: builtins.int
    DASH_AUDIO_FIELD_NUMBER: builtins.int
    DOLBY_FIELD_NUMBER: builtins.int
    quality: builtins.int
    """视频清晰度"""
    format: builtins.str
    """视频格式"""
    timelength: builtins.int
    """视频时长"""
    video_codecid: builtins.int
    """视频编码id"""
    @property
    def stream_list(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stream]:
        """视频流"""
    @property
    def dash_audio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DashItem]:
        """伴音流"""
    @property
    def dolby(self) -> global___DolbyItem:
        """杜比伴音流"""
    def __init__(
        self,
        *,
        quality: builtins.int = ...,
        format: builtins.str = ...,
        timelength: builtins.int = ...,
        video_codecid: builtins.int = ...,
        stream_list: collections.abc.Iterable[global___Stream] | None = ...,
        dash_audio: collections.abc.Iterable[global___DashItem] | None = ...,
        dolby: global___DolbyItem | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dolby", b"dolby"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dash_audio", b"dash_audio", "dolby", b"dolby", "format", b"format", "quality", b"quality", "stream_list", b"stream_list", "timelength", b"timelength", "video_codecid", b"video_codecid"]) -> None: ...

global___VideoInfo = VideoInfo

@typing_extensions.final
class ViewInfo(google.protobuf.message.Message):
    """展示信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class ExpConfigEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.bool
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.bool = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ExtDialogEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Dialog: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Dialog | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class ExtToastEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___Toast: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___Toast | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DIALOG_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    COUPON_INFO_FIELD_NUMBER: builtins.int
    DEMAND_NO_PAY_EPIDS_FIELD_NUMBER: builtins.int
    END_PAGE_FIELD_NUMBER: builtins.int
    EXP_CONFIG_FIELD_NUMBER: builtins.int
    POP_WIN_FIELD_NUMBER: builtins.int
    TRY_WATCH_PROMPT_BAR_FIELD_NUMBER: builtins.int
    PAY_TIP_FIELD_NUMBER: builtins.int
    HIGH_DEFINITION_TRIAL_INFO_FIELD_NUMBER: builtins.int
    EXT_DIALOG_FIELD_NUMBER: builtins.int
    ANIMATION_FIELD_NUMBER: builtins.int
    EXT_TOAST_FIELD_NUMBER: builtins.int
    @property
    def dialog(self) -> global___Dialog:
        """弹窗"""
    @property
    def toast(self) -> global___Toast:
        """Toast"""
    @property
    def coupon_info(self) -> global___CouponInfo:
        """优惠券信息"""
    @property
    def demand_no_pay_epids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """未支付剧集ID列表"""
    @property
    def end_page(self) -> global___EndPage:
        """结束页"""
    @property
    def exp_config(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.bool]:
        """扩展配置"""
    @property
    def pop_win(self) -> global___PopWin:
        """弹窗"""
    @property
    def try_watch_prompt_bar(self) -> global___PromptBar:
        """试看提示栏"""
    @property
    def pay_tip(self) -> global___PayTip:
        """支付提示信息"""
    @property
    def high_definition_trial_info(self) -> global___HighDefinitionTrialInfo:
        """高清试看提示信息"""
    @property
    def ext_dialog(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Dialog]:
        """弹窗扩展"""
    @property
    def animation(self) -> global___Animation:
        """动画"""
    @property
    def ext_toast(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___Toast]:
        """Toast扩展"""
    def __init__(
        self,
        *,
        dialog: global___Dialog | None = ...,
        toast: global___Toast | None = ...,
        coupon_info: global___CouponInfo | None = ...,
        demand_no_pay_epids: collections.abc.Iterable[builtins.int] | None = ...,
        end_page: global___EndPage | None = ...,
        exp_config: collections.abc.Mapping[builtins.str, builtins.bool] | None = ...,
        pop_win: global___PopWin | None = ...,
        try_watch_prompt_bar: global___PromptBar | None = ...,
        pay_tip: global___PayTip | None = ...,
        high_definition_trial_info: global___HighDefinitionTrialInfo | None = ...,
        ext_dialog: collections.abc.Mapping[builtins.str, global___Dialog] | None = ...,
        animation: global___Animation | None = ...,
        ext_toast: collections.abc.Mapping[builtins.str, global___Toast] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["animation", b"animation", "coupon_info", b"coupon_info", "dialog", b"dialog", "end_page", b"end_page", "high_definition_trial_info", b"high_definition_trial_info", "pay_tip", b"pay_tip", "pop_win", b"pop_win", "toast", b"toast", "try_watch_prompt_bar", b"try_watch_prompt_bar"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["animation", b"animation", "coupon_info", b"coupon_info", "demand_no_pay_epids", b"demand_no_pay_epids", "dialog", b"dialog", "end_page", b"end_page", "exp_config", b"exp_config", "ext_dialog", b"ext_dialog", "ext_toast", b"ext_toast", "high_definition_trial_info", b"high_definition_trial_info", "pay_tip", b"pay_tip", "pop_win", b"pop_win", "toast", b"toast", "try_watch_prompt_bar", b"try_watch_prompt_bar"]) -> None: ...

global___ViewInfo = ViewInfo

@typing_extensions.final
class WatchProgress(google.protobuf.message.Message):
    """观看进度信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_EP_ID_FIELD_NUMBER: builtins.int
    LAST_EP_INDEX_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    LAST_PLAY_CID_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    TOAST_WITHOUT_TIME_FIELD_NUMBER: builtins.int
    LAST_PLAY_AID_FIELD_NUMBER: builtins.int
    last_ep_id: builtins.int
    """上次观看的 EP ID"""
    last_ep_index: builtins.str
    """上次观看到的EP INDEX"""
    progress: builtins.int
    """上次观看的进度"""
    last_play_cid: builtins.int
    """上次观看的 CID"""
    @property
    def toast(self) -> global___Toast:
        """带时间的提示信息"""
    @property
    def toast_without_time(self) -> global___Toast:
        """不带时间的提示信息"""
    last_play_aid: builtins.int
    """上次观看的 AID"""
    def __init__(
        self,
        *,
        last_ep_id: builtins.int = ...,
        last_ep_index: builtins.str = ...,
        progress: builtins.int = ...,
        last_play_cid: builtins.int = ...,
        toast: global___Toast | None = ...,
        toast_without_time: global___Toast | None = ...,
        last_play_aid: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["toast", b"toast", "toast_without_time", b"toast_without_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_ep_id", b"last_ep_id", "last_ep_index", b"last_ep_index", "last_play_aid", b"last_play_aid", "last_play_cid", b"last_play_cid", "progress", b"progress", "toast", b"toast", "toast_without_time", b"toast_without_time"]) -> None: ...

global___WatchProgress = WatchProgress
